/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 44 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 97 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 108 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 121 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 136 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 153 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 172 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 193 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 216 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 241 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 268 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 297 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 328 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 361 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 396 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 433 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 472 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 515 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 560 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 607 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 656 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 707 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 760 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphtarget.sip"
#include <qmorphtarget.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphtarget.sip"
#include <qmorphtarget.h>
#line 815 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphtarget.sip"
#include <qmorphtarget.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qskeletonmapping.sip"
#include <qskeletonmapping.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qskeletonmapping.sip"
#include <qskeletonmapping.h>
#line 872 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphtarget.sip"
#include <qmorphtarget.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qskeletonmapping.sip"
#include <qskeletonmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qvertexblendanimation.sip"
#include <qvertexblendanimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qvertexblendanimation.sip"
#include <qvertexblendanimation.h>
#line 931 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_Qt3DAnimation[] = {
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'l', 'i', 'p', 'B', 'l', 'e', 'n', 'd', 'N', 'o', 'd', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'M', 'a', 'p', 'p', 'i', 'n', 'g', '*', '>', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'l', 'i', 'p', 'B', 'l', 'e', 'n', 'd', 'N', 'o', 'd', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'K', 'e', 'y', 'f', 'r', 'a', 'm', 'e', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'R', 'e', 'p', 'e', 'a', 't', 'M', 'o', 'd', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', '*', '>', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'C', 'l', 'i', 'p', 'A', 'n', 'i', 'm', 'a', 't', 'o', 'r', ':', ':', 'L', 'o', 'o', 'p', 's', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'C', 'l', 'i', 'p', 'L', 'o', 'a', 'd', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'K', 'e', 'y', 'F', 'r', 'a', 'm', 'e', ':', ':', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'M', 'o', 'r', 'p', 'h', 'i', 'n', 'g', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', '*', '>', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'M', 'o', 'r', 'p', 'h', 'T', 'a', 'r', 'g', 'e', 't', '*', '>', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'C', 'l', 'i', 'p', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'C', 'l', 'i', 'p', 'B', 'l', 'e', 'n', 'd', 'N', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'C', 'l', 'i', 'p', 'A', 'n', 'i', 'm', 'a', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'V', 'e', 'r', 't', 'e', 'x', 'B', 'l', 'e', 'n', 'd', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'C', 'l', 'i', 'p', 'L', 'o', 'a', 'd', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'B', 'l', 'e', 'n', 'd', 'e', 'd', 'C', 'l', 'i', 'p', 'A', 'n', 'i', 'm', 'a', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'C', 'l', 'i', 'p', 'B', 'l', 'e', 'n', 'd', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'C', 'l', 'i', 'p', 'D', 'a', 't', 'a', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'K', 'e', 'y', 'f', 'r', 'a', 'm', 'e', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'M', 'o', 'r', 'p', 'h', 'i', 'n', 'g', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'A', 's', 'p', 'e', 'c', 't', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', '*', '>', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'l', 'i', 'p', 'B', 'l', 'e', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'C', 'l', 'i', 'p', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'L', 'e', 'r', 'p', 'C', 'l', 'i', 'p', 'B', 'l', 'e', 'n', 'd', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'l', 'i', 'p', 'A', 'n', 'i', 'm', 'a', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'M', 'o', 'r', 'p', 'h', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'K', 'e', 'y', 'F', 'r', 'a', 'm', 'e', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    't', 'a', 'r', 'g', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'l', 'o', 'c', 'k', 0,
    'a', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    'f', 'r', 'a', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'T', 'i', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'f', 'f', 's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'S', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'P', 'o', 'i', 'n', 't', 0,
    'B', 'e', 'z', 'i', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', '3', 'D', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'C', 'l', 'i', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'P', 'o', 'i', 'n', 't', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 'L', 'i', 's', 't', 0,
    'b', 'l', 'e', 'n', 'd', 'F', 'a', 'c', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 's', 0,
    's', 'e', 't', 'T', 'a', 'r', 'g', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'a', 'd', 'd', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'g', 'e', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'I', 'n', 'd', 'e', 'x', 0,
    'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'M', 'o', 'r', 'p', 'h', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'r', 'i', 'g', 'h', 't', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'A', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'F', 'r', 'a', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'T', 'i', 'm', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    't', 'a', 'r', 'g', 'e', 't', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'l', 'e', 'n', 'd', 'T', 'r', 'e', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'l', 'e', 'f', 't', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'P', 'o', 'i', 'n', 't', 0,
    'l', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'S', 'c', 'a', 'l', 'e', 0,
    's', 't', 'a', 'r', 't', 'C', 'l', 'i', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'a', 'r', 't', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 's', 'e', 'C', 'l', 'i', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'i', 'p', 'D', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'r', 'p', 'h', 'T', 'a', 'r', 'g', 'e', 't', 'L', 'i', 's', 't', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 'e', 't', 'A', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'C', 'l', 'i', 'p', 0,
    's', 'e', 't', 'M', 'o', 'r', 'p', 'h', 'T', 'a', 'r', 'g', 'e', 't', 's', 0,
    's', 'e', 't', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 't', 'e', 0,
    's', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'a', 'r', 'g', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'a', 'd', 'd', 'M', 'o', 'r', 'p', 'h', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'a', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'K', 'e', 'y', 'F', 'r', 'a', 'm', 'e', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'K', 'e', 'y', 'F', 'r', 'a', 'm', 'e', 's', 0,
    'e', 'n', 'd', 'C', 'l', 'i', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'n', 'd', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'a', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'K', 'e', 'y', 'F', 'r', 'a', 'm', 'e', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'T', 'i', 'm', 'e', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'f', 'f', 's', 'e', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'K', 'e', 'y', 'F', 'r', 'a', 'm', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'K', 'e', 'y', 'f', 'r', 'a', 'm', 'e', 0,
    'r', 'u', 'n', 'n', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'l', 'e', 'n', 'd', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'L', 'i', 's', 't', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'N', 'a', 'm', 'e', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'L', 'i', 's', 't', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 's', 0,
    'e', 'a', 's', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'n', 't', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    'k', 'e', 'y', 'F', 'r', 'a', 'm', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'm', 'e', 't', 'h', 'o', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'S', 'c', 'a', 'l', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 0,
    's', 'e', 't', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    's', 'e', 't', 'J', 'o', 'i', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'T', 'a', 'r', 'g', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'a', 'r', 'g', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'd', 'd', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'd', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'a', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'C', 'l', 'i', 'p', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'o', 'm', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'o', 'r', 0,
    'k', 'e', 'y', 'f', 'r', 'a', 'm', 'e', 'L', 'i', 's', 't', 0,
    'p', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'B', 'l', 'e', 'n', 'd', 'T', 'r', 'e', 'e', 0,
    's', 'e', 't', 'K', 'e', 'y', 'f', 'r', 'a', 'm', 'e', 's', 0,
    's', 'e', 't', 'L', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'R', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 0,
    's', 'e', 't', 'S', 't', 'a', 'r', 't', 'C', 'l', 'i', 'p', 0,
    's', 'e', 't', 'S', 't', 'a', 'r', 't', 'M', 'o', 'd', 'e', 0,
    'a', 'd', 'd', 'K', 'e', 'y', 'f', 'r', 'a', 'm', 'e', 0,
    'b', 'l', 'e', 'n', 'd', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'N', 'a', 'm', 'e', 0,
    'c', 'l', 'i', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'n', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'C', 'l', 'i', 'p', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'a', 'd', 'd', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'g', 'e', 't', 'W', 'e', 'i', 'g', 'h', 't', 's', 0,
    'j', 'o', 'i', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'E', 'n', 'd', 'C', 'l', 'i', 'p', 0,
    's', 'e', 't', 'E', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'R', 'u', 'n', 'n', 'i', 'n', 'g', 0,
    's', 'e', 't', 'W', 'e', 'i', 'g', 'h', 't', 's', 0,
    't', 'a', 'r', 'g', 'e', 't', 'N', 'a', 'm', 'e', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'b', 'l', 'e', 'n', 'd', 'T', 'r', 'e', 'e', 0,
    'i', 's', 'R', 'u', 'n', 'n', 'i', 'n', 'g', 0,
    'l', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 0,
    's', 'e', 't', 'E', 'a', 's', 'i', 'n', 'g', 0,
    's', 'e', 't', 'E', 'n', 't', 'i', 't', 'y', 0,
    's', 'e', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'T', 'a', 'r', 'g', 'e', 't', 0,
    's', 't', 'a', 'r', 't', 'C', 'l', 'i', 'p', 0,
    's', 't', 'a', 'r', 't', 'M', 'o', 'd', 'e', 0,
    'C', 'o', 'n', 's', 't', 'a', 'n', 't', 0,
    'I', 'n', 'f', 'i', 'n', 'i', 't', 'e', 0,
    'N', 'o', 't', 'R', 'e', 'a', 'd', 'y', 0,
    'R', 'e', 'l', 'a', 't', 'i', 'v', 'e', 0,
    'b', 'a', 's', 'e', 'C', 'l', 'i', 'p', 0,
    'c', 'l', 'i', 'p', 'D', 'a', 't', 'a', 0,
    'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'g', 'e', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'm', 'a', 'p', 'p', 'i', 'n', 'g', 's', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'C', 'l', 'o', 'c', 'k', 0,
    's', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    'e', 'n', 'd', 'C', 'l', 'i', 'p', 0,
    'e', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    'R', 'e', 'p', 'e', 'a', 't', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    'e', 'a', 's', 'i', 'n', 'g', 0,
    'e', 'n', 't', 'i', 't', 'y', 0,
    'm', 'e', 't', 'h', 'o', 'd', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    's', 'o', 'u', 'r', 'c', 'e', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    't', 'a', 'r', 'g', 'e', 't', 0,
    'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 'n', 'e', '_', 0,
    'c', 'l', 'o', 'c', 'k', 0,
    'e', 'v', 'e', 'n', 't', 0,
    's', 't', 'a', 'r', 't', 0,
    'c', 'l', 'i', 'p', 0,
    'n', 'a', 'm', 'e', 0,
    's', 't', 'o', 'p', 0,
};

void sipVH_Qt3DAnimation_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DCore::QSceneChangePtr& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::Qt3DCore::QSceneChangePtr(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, SIP_NULLPTR);
}

bool sipVH_Qt3DAnimation_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_Qt3DAnimation_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_Qt3DAnimation_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_Qt3DAnimation_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_Qt3DAnimation_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_Qt3DAnimation_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_Qt3DAnimation_QAbstractAnimation(void **);}
static const sipTypeDef *sipSubClass_Qt3DAnimation_QAbstractAnimation(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 38 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
        static struct class_graph {
            const char *name;
            sipTypeDef **type;
            int yes, no;
        } graph[] = {
            {sipName_Qt3DAnimation__QAbstractAnimation, &sipType_Qt3DAnimation_QAbstractAnimation, 11, 1},
            {sipName_Qt3DAnimation__QAbstractAnimationClip, &sipType_Qt3DAnimation_QAbstractAnimationClip, 14, 2},
            {sipName_Qt3DAnimation__QAbstractChannelMapping, &sipType_Qt3DAnimation_QAbstractChannelMapping, 16, 3},
            {sipName_Qt3DAnimation__QAbstractClipAnimator, &sipType_Qt3DAnimation_QAbstractClipAnimator, 18, 4},
            {sipName_Qt3DAnimation__QAbstractClipBlendNode, &sipType_Qt3DAnimation_QAbstractClipBlendNode, 20, 5},
            {sipName_Qt3DAnimation__QAnimationAspect, &sipType_Qt3DAnimation_QAnimationAspect, -1, 6},
            {sipName_Qt3DAnimation__QAnimationController, &sipType_Qt3DAnimation_QAnimationController, -1, 7},
            {sipName_Qt3DAnimation__QAnimationGroup, &sipType_Qt3DAnimation_QAnimationGroup, -1, 8},
            {sipName_Qt3DAnimation__QChannelMapper, &sipType_Qt3DAnimation_QChannelMapper, -1, 9},
            {sipName_Qt3DAnimation__QClock, &sipType_Qt3DAnimation_QClock, -1, 10},
            {sipName_Qt3DAnimation__QMorphTarget, &sipType_Qt3DAnimation_QMorphTarget, -1, -1},
            {sipName_Qt3DAnimation__QKeyframeAnimation, &sipType_Qt3DAnimation_QKeyframeAnimation, -1, 12},
            {sipName_Qt3DAnimation__QMorphingAnimation, &sipType_Qt3DAnimation_QMorphingAnimation, -1, 13},
            {sipName_Qt3DAnimation__QVertexBlendAnimation, &sipType_Qt3DAnimation_QVertexBlendAnimation, -1, -1},
            {sipName_Qt3DAnimation__QAnimationClip, &sipType_Qt3DAnimation_QAnimationClip, -1, 15},
            {sipName_Qt3DAnimation__QAnimationClipLoader, &sipType_Qt3DAnimation_QAnimationClipLoader, -1, -1},
            {sipName_Qt3DAnimation__QChannelMapping, &sipType_Qt3DAnimation_QChannelMapping, -1, 17},
            {sipName_Qt3DAnimation__QSkeletonMapping, &sipType_Qt3DAnimation_QSkeletonMapping, -1, -1},
            {sipName_Qt3DAnimation__QBlendedClipAnimator, &sipType_Qt3DAnimation_QBlendedClipAnimator, -1, 19},
            {sipName_Qt3DAnimation__QClipAnimator, &sipType_Qt3DAnimation_QClipAnimator, -1, -1},
            {sipName_Qt3DAnimation__QAdditiveClipBlend, &sipType_Qt3DAnimation_QAdditiveClipBlend, -1, 21},
            {sipName_Qt3DAnimation__QClipBlendValue, &sipType_Qt3DAnimation_QClipBlendValue, -1, 22},
            {sipName_Qt3DAnimation__QLerpClipBlend, &sipType_Qt3DAnimation_QLerpClipBlend, -1, -1},
        };
        
        int i = 0;
        
        sipType = NULL;
        
        do
        {
            struct class_graph *cg = &graph[i];
        
            if (cg->name != NULL && sipCpp->inherits(cg->name))
            {
                sipType = *cg->type;
                i = cg->yes;
            }
            else
                i = cg->no;
        }
        while (i >= 0);
#line 1272 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationcmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DAnimation__QAbstractAnimation__AnimationType, SIP_NULLPTR, 0}, sipNameNr_AnimationType, 6, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DAnimation__QAbstractClipAnimator__Loops, SIP_NULLPTR, 0}, sipNameNr_Loops, 10, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DAnimation__QAnimationClipLoader__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 17, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DAnimation__QKeyFrame__InterpolationType, SIP_NULLPTR, 0}, sipNameNr_InterpolationType, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DAnimation__QKeyframeAnimation__RepeatMode, SIP_NULLPTR, 0}, sipNameNr_RepeatMode, 32, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DAnimation__QMorphingAnimation__Method, SIP_NULLPTR, 0}, sipNameNr_Method, 36, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_Qt3DAnimation[] = {
    &sipTypeDef_Qt3DAnimation_QSharedPointer_0100Qt3DAnimation_QClipBlendNodeCreatedChangeBase.mtd_base,
    &sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QAbstractAnimation.mtd_base,
    &sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QAbstractChannelMapping.mtd_base,
    &sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QAnimationGroup.mtd_base,
    &sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QMorphTarget.mtd_base,
    &sipTypeDef_Qt3DAnimation_QVector_0101Qt3DCore_QTransform.mtd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractAnimation.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractAnimationClip.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractChannelMapping.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractClipAnimator.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractClipBlendNode.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAdditiveClipBlend.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationAspect.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationClip.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationClipData.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationClipLoader.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationController.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationGroup.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QBlendedClipAnimator.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannel.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannelComponent.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannelMapper.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannelMapping.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClipAnimator.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClipBlendNodeCreatedChangeBase.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClipBlendValue.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClock.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QKeyFrame.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QKeyframeAnimation.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QLerpClipBlend.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QMorphTarget.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QMorphingAnimation.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QSkeletonMapping.ctd_base,
    &sipTypeDef_Qt3DAnimation_Qt3DAnimation_QVertexBlendAnimation.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"Qt3DAnimation::QClipBlendNodeCreatedChangeBasePtr", "QSharedPointer<Qt3DAnimation::QClipBlendNodeCreatedChangeBase>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_Qt3DAnimation_QtCore[] = {
    {"QChildEvent"},
    {"QEasingCurve"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_Qt3DAnimation_QtGui[] = {
    {"QVector2D"},
    {"QVector<float>"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from Qt3DCore. */
sipImportedTypeDef sipImportedTypes_Qt3DAnimation_Qt3DCore[] = {
    {"QSharedPointer<Qt3DCore::QSceneChange>"},
    {"Qt3DCore::QAbstractAspect"},
    {"Qt3DCore::QAbstractSkeleton"},
    {"Qt3DCore::QComponent"},
    {"Qt3DCore::QEntity"},
    {"Qt3DCore::QNode"},
    {"Qt3DCore::QNodeCreatedChangeBase"},
    {"Qt3DCore::QSceneChange"},
    {"Qt3DCore::QTransform"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from Qt3DRender. */
sipImportedTypeDef sipImportedTypes_Qt3DAnimation_Qt3DRender[] = {
    {"QVector<Qt3DRender::QAttribute*>"},
    {"Qt3DRender::QAttribute"},
    {"Qt3DRender::QGeometry"},
    {"Qt3DRender::QGeometryRenderer"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_Qt3DAnimation_QtCore, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_Qt3DAnimation_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.Qt3DCore", sipImportedTypes_Qt3DAnimation_Qt3DCore, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.Qt3DRender", sipImportedTypes_Qt3DAnimation_Qt3DRender, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_Qt3DAnimation_QAbstractAnimation, {4, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_Qt3DAnimation = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_Qt3DAnimation,
    0,
    sipStrings_Qt3DAnimation,
    importsTable,
    SIP_NULLPTR,
    40,
    sipExportedTypes_Qt3DAnimation,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    1,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_Qt3DAnimation;

sip_qt_metaobject_func sip_Qt3DAnimation_qt_metaobject;
sip_qt_metacall_func sip_Qt3DAnimation_qt_metacall;
sip_qt_metacast_func sip_Qt3DAnimation_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_Qt3DAnimation()
#else
PyMODINIT_FUNC PyInit_Qt3DAnimation()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.Qt3DAnimation",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_Qt3DAnimation = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_Qt3DAnimation == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_Qt3DAnimation, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_Qt3DAnimation_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_Qt3DAnimation_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_Qt3DAnimation_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_Qt3DAnimation_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_Qt3DAnimation, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
